@@ -22,6 +22,7 @@ from pytest_tui.utils import (
     TERMINAL_OUTPUT_FILE,
     TUI_RESULTS_FILE,
     TuiRerunTestGroup,
+    TuiSection,
     TuiSections,
     TuiTestResult,
     TuiTestResults,
@@ -80,6 +81,7 @@ def add_ansi_to_report(config: Config, report: TestReport) -> None:
 def pytest_sessionstart(session: pytest.Session) -> None:
     pass
 
+
 def pytest_cmdline_main(config: Config) -> None:
     # Set up the TUI-specific attributes on the config object:
     # Verbose (easier parsing of final test results)
@@ -110,10 +112,20 @@ def pytest_cmdline_main(config: Config) -> None:
         config._tui_reports = []
     if not hasattr(config, "_tui_test_results"):
         config._tui_test_results = TuiTestResults()
-    if not hasattr(config, "_tui_sections"):
-        config._tui_sections = TuiSections()
     if not hasattr(config, "_tui_terminal_out"):
         config._tui_terminal_out = tempfile.TemporaryFile("wb+")
+    if not hasattr(config, "_tui_sections"):
+        config._tui_sections = TuiSections(
+            live_log_sessionstart=TuiSection(name="pre_test", content=""),
+            test_session_starts=TuiSection(name="test_session_starts", content=""),
+            errors=TuiSection(name="errors", content=""),
+            failures=TuiSection(name="failures", content=""),
+            passes=TuiSection(name="passes", content=""),
+            warnings_summary=TuiSection(name="warnings_summary", content=""),
+            rerun_test_summary=TuiSection(name="rerun_test_summary", content=""),
+            short_test_summary=TuiSection(name="short_test_summary", content=""),
+            lastline=TuiSection(name="lastline", content=""),
+        )
 
 
 def pytest_report_teststatus(report: TestReport, config: Config) -> None:
@@ -164,6 +176,7 @@ def timestamp_result(config: Config, item: Item) -> None:
 def pytest_runtest_setup(item):
     timestamp_result(item.config, item)
 
+
 @pytest.hookimpl()
 def pytest_runtest_call(item):
     timestamp_result(item.config, item)
@@ -226,7 +239,9 @@ def pytest_configure(config: Config) -> None:
 
                 search = re.search(test_session_starts_test_matcher, s, re.MULTILINE)
                 if search:
-                    fqtn = re.search(test_session_starts_test_matcher, s, re.MULTILINE)[1].rstrip()
+                    fqtn = re.search(test_session_starts_test_matcher, s, re.MULTILINE)[
+                        1
+                    ].rstrip()
                     config._tui_sessionstart_current_fqtn = fqtn
                     config._tui_test_results.test_results.append(
                         TuiTestResult(fqtn=fqtn)
